synthetic\_aia\_mia.fetch\_data package
=======================================

Submodules
----------

synthetic\_aia\_mia.fetch\_data.adult module
--------------------------------------------

.. automodule:: synthetic_aia_mia.fetch_data.adult
   :members:
   :undoc-members:
   :show-inheritance:

synthetic\_aia\_mia.fetch\_data.split module
--------------------------------------------

.. automodule:: synthetic_aia_mia.fetch_data.split
   :members:
   :undoc-members:
   :show-inheritance:

synthetic\_aia\_mia.fetch\_data.utk module
------------------------------------------

.. automodule:: synthetic_aia_mia.fetch_data.utk
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: synthetic_aia_mia.fetch_data
   :members:
   :undoc-members:
   :show-inheritance:
